# %W% %G%
# Imakefile for mvfs_param.c
#
#
# ------------------------------------------------------------------
# | Copyright Unpublished, Atria Software, Inc.  All Rights        |
# | Reserved.  This software contains proprietary and confidential |
# | information of Atria and its suppliers.  Use, disclosure or    |
# | reproduction is prohibited without the prior express written   |
# | consent of Atria.                                              |
# ------------------------------------------------------------------
# 
# Makefile for mvfs parameters
# mvfs_param.c needs to be compiled on the target system
# to ensure it picks up target-specific parameter and
# offset values, and so that the user can configure it.
#

ROOT=
MAKE= make

# Common to MVFS installation on any version
MVFSLIB= libusrdrv.a
RM_AR_FILES= mvfs.o mvfs_param.o

# Macros to handle differences between HP-UX releases
CC10=	/usr/ccs/bin/cc
AR10=	/usr/ccs/bin/ar
LIB10=     /usr/conf/lib/$(MVFSLIB)
AR_FILES_11.11_32= "B.11.11_32/mvfs.o mvfs_param.o"
AR_FILES_11.11_64= "B.11.11_64/mvfs.o mvfs_param.o"

# Kernel options particular to each architecture
OFLAGS=+XixdUV -O
HP-PA.MACHOPTS=-Dhp9000s800
HP-PA.CCOPTS= -Wp,-H300000 $(OFLAGS) +Hx0 +R25 
HP-PA.NOGLOOPTS= +XiUVx
HP-PA.GLOOKOPTS= +XiUx

HP-10.COPTS= "${IDENT} ${OPTIONS} -DKERNEL -D_KERNEL \
	-D_KERNEL_BUILD -D_UNSUPPORTED -DATRIA_HPUX10 +DA1.0 +DS1.1"
HP-11.COPTS.LP64= "${IDENT} ${OPTIONS} -DKERNEL -D_KERNEL \
	-D_KERNEL_BUILD -D_UNSUPPORTED -DATRIA_HPUX10 +DA2.0W +DS2.0"

# no default, caller must specifiy action 
unspecified:
	@echo "Error: No action specified.  Must specify one of: install, regen, deinstall"

# three operations are supported by this makefile:
#   a) installing the MVFS (install)
#   b) rebuilding the MVFS after tuning mvfs_param.c (regen)
#   c) deinstalling the MVFS (deinstall)
# 

regen:
	@$(MAKE) -f mvfs_param.mk install

install:
	@case `uname -r` in \
    B.11.11) \
      if [ `getconf KERNEL_BITS` -eq 32 ]; then \
       $(MAKE) -f mvfs_param.mk CC=$(CC10) AR=$(AR10) OPTS=$(HP-10.COPTS) \
          DEST=$(LIB10) AR_FILES=$(AR_FILES_11.11_32) build.mvfs ; \
      else   \
       $(MAKE) -f mvfs_param.mk CC=$(CC10) AR=$(AR10) OPTS=$(HP-11.COPTS.LP64) \
          DEST=$(LIB10) AR_FILES=$(AR_FILES_11.11_64) build.mvfs ; \
      fi \
    ;;  \
    esac

build.mvfs: mvfs_param.o
	$(AR) r $(DEST) $(AR_FILES)

mvfs_param.o: mvfs_param.c
	$(CC) -c -w -I.. -I../h $(OPTS) $(HP-PA.MACHOPTS) $(HP-PA.CCOPTS) $(HP-PA.NOGLOOPTS) mvfs_param.c


# deinstall MVFS: remove objects from libusrdrv.a, and if it is now empty,
#                 remove the archive itself
#
deinstall:
	@case `uname -r` in \
    *.11.*) \
        $(MAKE) -f mvfs_param.mk AR=$(AR10) DEST=$(LIB10) rm.mvfs  \
    ;; \
    esac

rm.mvfs:   
	-rm mvfs_param.o
	-$(AR) d $(DEST) $(RM_AR_FILES)
	@if [ "X`$(AR) tv $(DEST)`" = "X" ] ; then \
		rm $(DEST); fi

